|
Expressiveness for queries
|
|
3
|
340
|
June 6, 2022
|
|
UInt128 to Float64 conversion
|
|
2
|
777
|
June 6, 2022
|
|
How to tranform a vector into a matrix?
|
|
5
|
927
|
June 6, 2022
|
|
Array broadcasting slower than numpy?
|
|
20
|
1122
|
June 4, 2022
|
|
Performance slowdown on AMD with Windows10 compared to Intel with Linux (arch)
|
|
7
|
1171
|
June 3, 2022
|
|
How to avoid vectors of abstract types?
|
|
5
|
521
|
June 3, 2022
|
|
Julia vs Trilinos
|
|
8
|
909
|
June 2, 2022
|
|
How to count heap allocations easily?
|
|
4
|
1015
|
June 1, 2022
|
|
Precompute some values of a function
|
|
7
|
795
|
June 1, 2022
|
|
Understanding message passing with pmap
|
|
3
|
576
|
June 1, 2022
|
|
Help with increasing performance in badly coded functions
|
|
5
|
533
|
May 31, 2022
|
|
Anonymous function performance
|
|
9
|
1133
|
May 31, 2022
|
|
Optionally multi threaded for loop
|
|
9
|
1426
|
May 31, 2022
|
|
Need help with example; Mixture Density Networks from Site
|
|
25
|
1186
|
May 31, 2022
|
|
Package development tools - in environment but not dependency
|
|
6
|
500
|
May 31, 2022
|
|
Contents of the function run well when timed alone, but not when they are in a loop inside the function
|
|
8
|
1076
|
May 31, 2022
|
|
Extra allocations/time when a function is returned from another function than defined directly
|
|
6
|
420
|
May 30, 2022
|
|
AdaptiveMCMC
|
|
9
|
900
|
May 30, 2022
|
|
Mv() in Windows
|
|
6
|
640
|
May 30, 2022
|
|
Naive lookup table with lots of allocations
|
|
11
|
744
|
May 30, 2022
|
|
Using serial ports
|
|
8
|
2626
|
May 28, 2022
|
|
Why is dot plus faster?
|
|
6
|
675
|
May 28, 2022
|
|
Is it possible to see performant string processing without sacrificing ease of use in Julia one day?
|
|
7
|
993
|
May 28, 2022
|
|
Problems with Optimising Function
|
|
2
|
314
|
May 27, 2022
|
|
Arithmetic broadcasting in Julia 5x slower than MATLAB
|
|
17
|
1407
|
May 26, 2022
|
|
Type instability with tuples of functions and parameters
|
|
13
|
880
|
May 25, 2022
|
|
Yet another TCO thread
|
|
5
|
2550
|
May 25, 2022
|
|
How to efficiently handle parallelism on a DistributedArray
|
|
8
|
816
|
May 24, 2022
|
|
Passing struct with Union type to other function
|
|
6
|
688
|
May 23, 2022
|
|
If mutiple dispatch is done at compile time, wouldn't that make things faster?
|
|
3
|
608
|
May 23, 2022
|